# Square Connect Ruby SDK Technical Reference

---
## The Square Connect Ruby SDK is retired (EOL) as of 2019-08-15 and will no longer receive bug fixes or product updates.
---

This SDK is automatically generated by the
[Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0
- Package version: 2.20190724.1
- Build package: io.swagger.codegen.languages.RubyClientCodegen

For more information, please visit
[https://squareup.com/developers](https://squareup.com/developers)

---

## Installation of Square Connect Ruby SDK

### Option1: RubyGems
The Ruby SDK is published as a gem. Simply run:

```
$ gem install square_connect
```

Or add this line to your Gemfile:

```
gem 'square_connect'
```

### Option 2: Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/square/connect-ruby-sdk, then add the following in the Gemfile:

    gem 'square_connect', :git => 'https://github.com/square/connect-ruby-sdk.git'

### Option 3: Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'square_connect'

# Setup authorization
SquareConnect.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

# The SDK throws an exception if a Connect endpoint responds with anything besides 200 (success).
# This block catches any exceptions that occur from the request.
locations_api = SquareConnect::LocationsApi.new
begin
  locations = locations_api.list_locations.locations
rescue SquareConnect::ApiError => e
  puts "Error encountered while loading the locations: #{e.message}"
end
```

## Documentation for API Endpoints

All URIs are relative to *https://connect.squareup.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SquareConnect::ApplePayApi* | [**register_domain**](ApplePayApi.md#register_domain) | **POST** /v2/apple-pay/domains | RegisterDomain
*SquareConnect::CatalogApi* | [**batch_delete_catalog_objects**](CatalogApi.md#batch_delete_catalog_objects) | **POST** /v2/catalog/batch-delete | BatchDeleteCatalogObjects
*SquareConnect::CatalogApi* | [**batch_retrieve_catalog_objects**](CatalogApi.md#batch_retrieve_catalog_objects) | **POST** /v2/catalog/batch-retrieve | BatchRetrieveCatalogObjects
*SquareConnect::CatalogApi* | [**batch_upsert_catalog_objects**](CatalogApi.md#batch_upsert_catalog_objects) | **POST** /v2/catalog/batch-upsert | BatchUpsertCatalogObjects
*SquareConnect::CatalogApi* | [**catalog_info**](CatalogApi.md#catalog_info) | **GET** /v2/catalog/info | CatalogInfo
*SquareConnect::CatalogApi* | [**delete_catalog_object**](CatalogApi.md#delete_catalog_object) | **DELETE** /v2/catalog/object/{object_id} | DeleteCatalogObject
*SquareConnect::CatalogApi* | [**list_catalog**](CatalogApi.md#list_catalog) | **GET** /v2/catalog/list | ListCatalog
*SquareConnect::CatalogApi* | [**retrieve_catalog_object**](CatalogApi.md#retrieve_catalog_object) | **GET** /v2/catalog/object/{object_id} | RetrieveCatalogObject
*SquareConnect::CatalogApi* | [**search_catalog_objects**](CatalogApi.md#search_catalog_objects) | **POST** /v2/catalog/search | SearchCatalogObjects
*SquareConnect::CatalogApi* | [**update_item_modifier_lists**](CatalogApi.md#update_item_modifier_lists) | **POST** /v2/catalog/update-item-modifier-lists | UpdateItemModifierLists
*SquareConnect::CatalogApi* | [**update_item_taxes**](CatalogApi.md#update_item_taxes) | **POST** /v2/catalog/update-item-taxes | UpdateItemTaxes
*SquareConnect::CatalogApi* | [**upsert_catalog_object**](CatalogApi.md#upsert_catalog_object) | **POST** /v2/catalog/object | UpsertCatalogObject
*SquareConnect::CheckoutApi* | [**create_checkout**](CheckoutApi.md#create_checkout) | **POST** /v2/locations/{location_id}/checkouts | CreateCheckout
*SquareConnect::CustomersApi* | [**create_customer**](CustomersApi.md#create_customer) | **POST** /v2/customers | CreateCustomer
*SquareConnect::CustomersApi* | [**create_customer_card**](CustomersApi.md#create_customer_card) | **POST** /v2/customers/{customer_id}/cards | CreateCustomerCard
*SquareConnect::CustomersApi* | [**delete_customer**](CustomersApi.md#delete_customer) | **DELETE** /v2/customers/{customer_id} | DeleteCustomer
*SquareConnect::CustomersApi* | [**delete_customer_card**](CustomersApi.md#delete_customer_card) | **DELETE** /v2/customers/{customer_id}/cards/{card_id} | DeleteCustomerCard
*SquareConnect::CustomersApi* | [**list_customers**](CustomersApi.md#list_customers) | **GET** /v2/customers | ListCustomers
*SquareConnect::CustomersApi* | [**retrieve_customer**](CustomersApi.md#retrieve_customer) | **GET** /v2/customers/{customer_id} | RetrieveCustomer
*SquareConnect::CustomersApi* | [**search_customers**](CustomersApi.md#search_customers) | **POST** /v2/customers/search | SearchCustomers
*SquareConnect::CustomersApi* | [**update_customer**](CustomersApi.md#update_customer) | **PUT** /v2/customers/{customer_id} | UpdateCustomer
*SquareConnect::EmployeesApi* | [**list_employees**](EmployeesApi.md#list_employees) | **GET** /v2/employees | ListEmployees
*SquareConnect::EmployeesApi* | [**retrieve_employee**](EmployeesApi.md#retrieve_employee) | **GET** /v2/employees/{id} | RetrieveEmployee
*SquareConnect::InventoryApi* | [**batch_change_inventory**](InventoryApi.md#batch_change_inventory) | **POST** /v2/inventory/batch-change | BatchChangeInventory
*SquareConnect::InventoryApi* | [**batch_retrieve_inventory_changes**](InventoryApi.md#batch_retrieve_inventory_changes) | **POST** /v2/inventory/batch-retrieve-changes | BatchRetrieveInventoryChanges
*SquareConnect::InventoryApi* | [**batch_retrieve_inventory_counts**](InventoryApi.md#batch_retrieve_inventory_counts) | **POST** /v2/inventory/batch-retrieve-counts | BatchRetrieveInventoryCounts
*SquareConnect::InventoryApi* | [**retrieve_inventory_adjustment**](InventoryApi.md#retrieve_inventory_adjustment) | **GET** /v2/inventory/adjustment/{adjustment_id} | RetrieveInventoryAdjustment
*SquareConnect::InventoryApi* | [**retrieve_inventory_changes**](InventoryApi.md#retrieve_inventory_changes) | **GET** /v2/inventory/{catalog_object_id}/changes | RetrieveInventoryChanges
*SquareConnect::InventoryApi* | [**retrieve_inventory_count**](InventoryApi.md#retrieve_inventory_count) | **GET** /v2/inventory/{catalog_object_id} | RetrieveInventoryCount
*SquareConnect::InventoryApi* | [**retrieve_inventory_physical_count**](InventoryApi.md#retrieve_inventory_physical_count) | **GET** /v2/inventory/physical-count/{physical_count_id} | RetrieveInventoryPhysicalCount
*SquareConnect::LaborApi* | [**create_break_type**](LaborApi.md#create_break_type) | **POST** /v2/labor/break-types | CreateBreakType
*SquareConnect::LaborApi* | [**create_shift**](LaborApi.md#create_shift) | **POST** /v2/labor/shifts | CreateShift
*SquareConnect::LaborApi* | [**delete_break_type**](LaborApi.md#delete_break_type) | **DELETE** /v2/labor/break-types/{id} | DeleteBreakType
*SquareConnect::LaborApi* | [**delete_shift**](LaborApi.md#delete_shift) | **DELETE** /v2/labor/shifts/{id} | DeleteShift
*SquareConnect::LaborApi* | [**get_break_type**](LaborApi.md#get_break_type) | **GET** /v2/labor/break-types/{id} | GetBreakType
*SquareConnect::LaborApi* | [**get_employee_wage**](LaborApi.md#get_employee_wage) | **GET** /v2/labor/employee-wages/{id} | GetEmployeeWage
*SquareConnect::LaborApi* | [**get_shift**](LaborApi.md#get_shift) | **GET** /v2/labor/shifts/{id} | GetShift
*SquareConnect::LaborApi* | [**list_break_types**](LaborApi.md#list_break_types) | **GET** /v2/labor/break-types | ListBreakTypes
*SquareConnect::LaborApi* | [**list_employee_wages**](LaborApi.md#list_employee_wages) | **GET** /v2/labor/employee-wages | ListEmployeeWages
*SquareConnect::LaborApi* | [**list_workweek_configs**](LaborApi.md#list_workweek_configs) | **GET** /v2/labor/workweek-configs | ListWorkweekConfigs
*SquareConnect::LaborApi* | [**search_shifts**](LaborApi.md#search_shifts) | **POST** /v2/labor/shifts/search | SearchShifts
*SquareConnect::LaborApi* | [**update_break_type**](LaborApi.md#update_break_type) | **PUT** /v2/labor/break-types/{id} | UpdateBreakType
*SquareConnect::LaborApi* | [**update_shift**](LaborApi.md#update_shift) | **PUT** /v2/labor/shifts/{id} | UpdateShift
*SquareConnect::LaborApi* | [**update_workweek_config**](LaborApi.md#update_workweek_config) | **PUT** /v2/labor/workweek-configs/{id} | UpdateWorkweekConfig
*SquareConnect::LocationsApi* | [**list_locations**](LocationsApi.md#list_locations) | **GET** /v2/locations | ListLocations
*SquareConnect::MobileAuthorizationApi* | [**create_mobile_authorization_code**](MobileAuthorizationApi.md#create_mobile_authorization_code) | **POST** /mobile/authorization-code | CreateMobileAuthorizationCode
*SquareConnect::OAuthApi* | [**obtain_token**](OAuthApi.md#obtain_token) | **POST** /oauth2/token | ObtainToken
*SquareConnect::OAuthApi* | [**renew_token**](OAuthApi.md#renew_token) | **POST** /oauth2/clients/{client_id}/access-token/renew | RenewToken
*SquareConnect::OAuthApi* | [**revoke_token**](OAuthApi.md#revoke_token) | **POST** /oauth2/revoke | RevokeToken
*SquareConnect::OrdersApi* | [**batch_retrieve_orders**](OrdersApi.md#batch_retrieve_orders) | **POST** /v2/locations/{location_id}/orders/batch-retrieve | BatchRetrieveOrders
*SquareConnect::OrdersApi* | [**create_order**](OrdersApi.md#create_order) | **POST** /v2/locations/{location_id}/orders | CreateOrder
*SquareConnect::OrdersApi* | [**search_orders**](OrdersApi.md#search_orders) | **POST** /v2/orders/search | SearchOrders
*SquareConnect::ReportingApi* | [**list_additional_recipient_receivable_refunds**](ReportingApi.md#list_additional_recipient_receivable_refunds) | **GET** /v2/locations/{location_id}/additional-recipient-receivable-refunds | ListAdditionalRecipientReceivableRefunds
*SquareConnect::ReportingApi* | [**list_additional_recipient_receivables**](ReportingApi.md#list_additional_recipient_receivables) | **GET** /v2/locations/{location_id}/additional-recipient-receivables | ListAdditionalRecipientReceivables
*SquareConnect::TransactionsApi* | [**capture_transaction**](TransactionsApi.md#capture_transaction) | **POST** /v2/locations/{location_id}/transactions/{transaction_id}/capture | CaptureTransaction
*SquareConnect::TransactionsApi* | [**charge**](TransactionsApi.md#charge) | **POST** /v2/locations/{location_id}/transactions | Charge
*SquareConnect::TransactionsApi* | [**create_refund**](TransactionsApi.md#create_refund) | **POST** /v2/locations/{location_id}/transactions/{transaction_id}/refund | CreateRefund
*SquareConnect::TransactionsApi* | [**list_refunds**](TransactionsApi.md#list_refunds) | **GET** /v2/locations/{location_id}/refunds | ListRefunds
*SquareConnect::TransactionsApi* | [**list_transactions**](TransactionsApi.md#list_transactions) | **GET** /v2/locations/{location_id}/transactions | ListTransactions
*SquareConnect::TransactionsApi* | [**retrieve_transaction**](TransactionsApi.md#retrieve_transaction) | **GET** /v2/locations/{location_id}/transactions/{transaction_id} | RetrieveTransaction
*SquareConnect::TransactionsApi* | [**void_transaction**](TransactionsApi.md#void_transaction) | **POST** /v2/locations/{location_id}/transactions/{transaction_id}/void | VoidTransaction
*SquareConnect::V1EmployeesApi* | [**create_employee**](V1EmployeesApi.md#create_employee) | **POST** /v1/me/employees | CreateEmployee
*SquareConnect::V1EmployeesApi* | [**create_employee_role**](V1EmployeesApi.md#create_employee_role) | **POST** /v1/me/roles | CreateEmployeeRole
*SquareConnect::V1EmployeesApi* | [**create_timecard**](V1EmployeesApi.md#create_timecard) | **POST** /v1/me/timecards | CreateTimecard
*SquareConnect::V1EmployeesApi* | [**delete_timecard**](V1EmployeesApi.md#delete_timecard) | **DELETE** /v1/me/timecards/{timecard_id} | DeleteTimecard
*SquareConnect::V1EmployeesApi* | [**list_cash_drawer_shifts**](V1EmployeesApi.md#list_cash_drawer_shifts) | **GET** /v1/{location_id}/cash-drawer-shifts | ListCashDrawerShifts
*SquareConnect::V1EmployeesApi* | [**list_employee_roles**](V1EmployeesApi.md#list_employee_roles) | **GET** /v1/me/roles | ListEmployeeRoles
*SquareConnect::V1EmployeesApi* | [**list_employees**](V1EmployeesApi.md#list_employees) | **GET** /v1/me/employees | ListEmployees
*SquareConnect::V1EmployeesApi* | [**list_timecard_events**](V1EmployeesApi.md#list_timecard_events) | **GET** /v1/me/timecards/{timecard_id}/events | ListTimecardEvents
*SquareConnect::V1EmployeesApi* | [**list_timecards**](V1EmployeesApi.md#list_timecards) | **GET** /v1/me/timecards | ListTimecards
*SquareConnect::V1EmployeesApi* | [**retrieve_cash_drawer_shift**](V1EmployeesApi.md#retrieve_cash_drawer_shift) | **GET** /v1/{location_id}/cash-drawer-shifts/{shift_id} | RetrieveCashDrawerShift
*SquareConnect::V1EmployeesApi* | [**retrieve_employee**](V1EmployeesApi.md#retrieve_employee) | **GET** /v1/me/employees/{employee_id} | RetrieveEmployee
*SquareConnect::V1EmployeesApi* | [**retrieve_employee_role**](V1EmployeesApi.md#retrieve_employee_role) | **GET** /v1/me/roles/{role_id} | RetrieveEmployeeRole
*SquareConnect::V1EmployeesApi* | [**retrieve_timecard**](V1EmployeesApi.md#retrieve_timecard) | **GET** /v1/me/timecards/{timecard_id} | RetrieveTimecard
*SquareConnect::V1EmployeesApi* | [**update_employee**](V1EmployeesApi.md#update_employee) | **PUT** /v1/me/employees/{employee_id} | UpdateEmployee
*SquareConnect::V1EmployeesApi* | [**update_employee_role**](V1EmployeesApi.md#update_employee_role) | **PUT** /v1/me/roles/{role_id} | UpdateEmployeeRole
*SquareConnect::V1EmployeesApi* | [**update_timecard**](V1EmployeesApi.md#update_timecard) | **PUT** /v1/me/timecards/{timecard_id} | UpdateTimecard
*SquareConnect::V1ItemsApi* | [**adjust_inventory**](V1ItemsApi.md#adjust_inventory) | **POST** /v1/{location_id}/inventory/{variation_id} | AdjustInventory
*SquareConnect::V1ItemsApi* | [**apply_fee**](V1ItemsApi.md#apply_fee) | **PUT** /v1/{location_id}/items/{item_id}/fees/{fee_id} | ApplyFee
*SquareConnect::V1ItemsApi* | [**apply_modifier_list**](V1ItemsApi.md#apply_modifier_list) | **PUT** /v1/{location_id}/items/{item_id}/modifier-lists/{modifier_list_id} | ApplyModifierList
*SquareConnect::V1ItemsApi* | [**create_category**](V1ItemsApi.md#create_category) | **POST** /v1/{location_id}/categories | CreateCategory
*SquareConnect::V1ItemsApi* | [**create_discount**](V1ItemsApi.md#create_discount) | **POST** /v1/{location_id}/discounts | CreateDiscount
*SquareConnect::V1ItemsApi* | [**create_fee**](V1ItemsApi.md#create_fee) | **POST** /v1/{location_id}/fees | CreateFee
*SquareConnect::V1ItemsApi* | [**create_item**](V1ItemsApi.md#create_item) | **POST** /v1/{location_id}/items | CreateItem
*SquareConnect::V1ItemsApi* | [**create_modifier_list**](V1ItemsApi.md#create_modifier_list) | **POST** /v1/{location_id}/modifier-lists | CreateModifierList
*SquareConnect::V1ItemsApi* | [**create_modifier_option**](V1ItemsApi.md#create_modifier_option) | **POST** /v1/{location_id}/modifier-lists/{modifier_list_id}/modifier-options | CreateModifierOption
*SquareConnect::V1ItemsApi* | [**create_page**](V1ItemsApi.md#create_page) | **POST** /v1/{location_id}/pages | CreatePage
*SquareConnect::V1ItemsApi* | [**create_variation**](V1ItemsApi.md#create_variation) | **POST** /v1/{location_id}/items/{item_id}/variations | CreateVariation
*SquareConnect::V1ItemsApi* | [**delete_category**](V1ItemsApi.md#delete_category) | **DELETE** /v1/{location_id}/categories/{category_id} | DeleteCategory
*SquareConnect::V1ItemsApi* | [**delete_discount**](V1ItemsApi.md#delete_discount) | **DELETE** /v1/{location_id}/discounts/{discount_id} | DeleteDiscount
*SquareConnect::V1ItemsApi* | [**delete_fee**](V1ItemsApi.md#delete_fee) | **DELETE** /v1/{location_id}/fees/{fee_id} | DeleteFee
*SquareConnect::V1ItemsApi* | [**delete_item**](V1ItemsApi.md#delete_item) | **DELETE** /v1/{location_id}/items/{item_id} | DeleteItem
*SquareConnect::V1ItemsApi* | [**delete_modifier_list**](V1ItemsApi.md#delete_modifier_list) | **DELETE** /v1/{location_id}/modifier-lists/{modifier_list_id} | DeleteModifierList
*SquareConnect::V1ItemsApi* | [**delete_modifier_option**](V1ItemsApi.md#delete_modifier_option) | **DELETE** /v1/{location_id}/modifier-lists/{modifier_list_id}/modifier-options/{modifier_option_id} | DeleteModifierOption
*SquareConnect::V1ItemsApi* | [**delete_page**](V1ItemsApi.md#delete_page) | **DELETE** /v1/{location_id}/pages/{page_id} | DeletePage
*SquareConnect::V1ItemsApi* | [**delete_page_cell**](V1ItemsApi.md#delete_page_cell) | **DELETE** /v1/{location_id}/pages/{page_id}/cells | DeletePageCell
*SquareConnect::V1ItemsApi* | [**delete_variation**](V1ItemsApi.md#delete_variation) | **DELETE** /v1/{location_id}/items/{item_id}/variations/{variation_id} | DeleteVariation
*SquareConnect::V1ItemsApi* | [**list_categories**](V1ItemsApi.md#list_categories) | **GET** /v1/{location_id}/categories | ListCategories
*SquareConnect::V1ItemsApi* | [**list_discounts**](V1ItemsApi.md#list_discounts) | **GET** /v1/{location_id}/discounts | ListDiscounts
*SquareConnect::V1ItemsApi* | [**list_fees**](V1ItemsApi.md#list_fees) | **GET** /v1/{location_id}/fees | ListFees
*SquareConnect::V1ItemsApi* | [**list_inventory**](V1ItemsApi.md#list_inventory) | **GET** /v1/{location_id}/inventory | ListInventory
*SquareConnect::V1ItemsApi* | [**list_items**](V1ItemsApi.md#list_items) | **GET** /v1/{location_id}/items | ListItems
*SquareConnect::V1ItemsApi* | [**list_modifier_lists**](V1ItemsApi.md#list_modifier_lists) | **GET** /v1/{location_id}/modifier-lists | ListModifierLists
*SquareConnect::V1ItemsApi* | [**list_pages**](V1ItemsApi.md#list_pages) | **GET** /v1/{location_id}/pages | ListPages
*SquareConnect::V1ItemsApi* | [**remove_fee**](V1ItemsApi.md#remove_fee) | **DELETE** /v1/{location_id}/items/{item_id}/fees/{fee_id} | RemoveFee
*SquareConnect::V1ItemsApi* | [**remove_modifier_list**](V1ItemsApi.md#remove_modifier_list) | **DELETE** /v1/{location_id}/items/{item_id}/modifier-lists/{modifier_list_id} | RemoveModifierList
*SquareConnect::V1ItemsApi* | [**retrieve_item**](V1ItemsApi.md#retrieve_item) | **GET** /v1/{location_id}/items/{item_id} | RetrieveItem
*SquareConnect::V1ItemsApi* | [**retrieve_modifier_list**](V1ItemsApi.md#retrieve_modifier_list) | **GET** /v1/{location_id}/modifier-lists/{modifier_list_id} | RetrieveModifierList
*SquareConnect::V1ItemsApi* | [**update_category**](V1ItemsApi.md#update_category) | **PUT** /v1/{location_id}/categories/{category_id} | UpdateCategory
*SquareConnect::V1ItemsApi* | [**update_discount**](V1ItemsApi.md#update_discount) | **PUT** /v1/{location_id}/discounts/{discount_id} | UpdateDiscount
*SquareConnect::V1ItemsApi* | [**update_fee**](V1ItemsApi.md#update_fee) | **PUT** /v1/{location_id}/fees/{fee_id} | UpdateFee
*SquareConnect::V1ItemsApi* | [**update_item**](V1ItemsApi.md#update_item) | **PUT** /v1/{location_id}/items/{item_id} | UpdateItem
*SquareConnect::V1ItemsApi* | [**update_modifier_list**](V1ItemsApi.md#update_modifier_list) | **PUT** /v1/{location_id}/modifier-lists/{modifier_list_id} | UpdateModifierList
*SquareConnect::V1ItemsApi* | [**update_modifier_option**](V1ItemsApi.md#update_modifier_option) | **PUT** /v1/{location_id}/modifier-lists/{modifier_list_id}/modifier-options/{modifier_option_id} | UpdateModifierOption
*SquareConnect::V1ItemsApi* | [**update_page**](V1ItemsApi.md#update_page) | **PUT** /v1/{location_id}/pages/{page_id} | UpdatePage
*SquareConnect::V1ItemsApi* | [**update_page_cell**](V1ItemsApi.md#update_page_cell) | **PUT** /v1/{location_id}/pages/{page_id}/cells | UpdatePageCell
*SquareConnect::V1ItemsApi* | [**update_variation**](V1ItemsApi.md#update_variation) | **PUT** /v1/{location_id}/items/{item_id}/variations/{variation_id} | UpdateVariation
*SquareConnect::V1LocationsApi* | [**list_locations**](V1LocationsApi.md#list_locations) | **GET** /v1/me/locations | ListLocations
*SquareConnect::V1LocationsApi* | [**retrieve_business**](V1LocationsApi.md#retrieve_business) | **GET** /v1/me | RetrieveBusiness
*SquareConnect::V1TransactionsApi* | [**create_refund**](V1TransactionsApi.md#create_refund) | **POST** /v1/{location_id}/refunds | CreateRefund
*SquareConnect::V1TransactionsApi* | [**list_bank_accounts**](V1TransactionsApi.md#list_bank_accounts) | **GET** /v1/{location_id}/bank-accounts | ListBankAccounts
*SquareConnect::V1TransactionsApi* | [**list_orders**](V1TransactionsApi.md#list_orders) | **GET** /v1/{location_id}/orders | ListOrders
*SquareConnect::V1TransactionsApi* | [**list_payments**](V1TransactionsApi.md#list_payments) | **GET** /v1/{location_id}/payments | ListPayments
*SquareConnect::V1TransactionsApi* | [**list_refunds**](V1TransactionsApi.md#list_refunds) | **GET** /v1/{location_id}/refunds | ListRefunds
*SquareConnect::V1TransactionsApi* | [**list_settlements**](V1TransactionsApi.md#list_settlements) | **GET** /v1/{location_id}/settlements | ListSettlements
*SquareConnect::V1TransactionsApi* | [**retrieve_bank_account**](V1TransactionsApi.md#retrieve_bank_account) | **GET** /v1/{location_id}/bank-accounts/{bank_account_id} | RetrieveBankAccount
*SquareConnect::V1TransactionsApi* | [**retrieve_order**](V1TransactionsApi.md#retrieve_order) | **GET** /v1/{location_id}/orders/{order_id} | RetrieveOrder
*SquareConnect::V1TransactionsApi* | [**retrieve_payment**](V1TransactionsApi.md#retrieve_payment) | **GET** /v1/{location_id}/payments/{payment_id} | RetrievePayment
*SquareConnect::V1TransactionsApi* | [**retrieve_settlement**](V1TransactionsApi.md#retrieve_settlement) | **GET** /v1/{location_id}/settlements/{settlement_id} | RetrieveSettlement
*SquareConnect::V1TransactionsApi* | [**update_order**](V1TransactionsApi.md#update_order) | **PUT** /v1/{location_id}/orders/{order_id} | UpdateOrder


## Documentation for Models

 - [SquareConnect::AdditionalRecipient](AdditionalRecipient.md)
 - [SquareConnect::AdditionalRecipientReceivable](AdditionalRecipientReceivable.md)
 - [SquareConnect::AdditionalRecipientReceivableRefund](AdditionalRecipientReceivableRefund.md)
 - [SquareConnect::Address](Address.md)
 - [SquareConnect::BatchChangeInventoryRequest](BatchChangeInventoryRequest.md)
 - [SquareConnect::BatchChangeInventoryResponse](BatchChangeInventoryResponse.md)
 - [SquareConnect::BatchDeleteCatalogObjectsRequest](BatchDeleteCatalogObjectsRequest.md)
 - [SquareConnect::BatchDeleteCatalogObjectsResponse](BatchDeleteCatalogObjectsResponse.md)
 - [SquareConnect::BatchRetrieveCatalogObjectsRequest](BatchRetrieveCatalogObjectsRequest.md)
 - [SquareConnect::BatchRetrieveCatalogObjectsResponse](BatchRetrieveCatalogObjectsResponse.md)
 - [SquareConnect::BatchRetrieveInventoryChangesRequest](BatchRetrieveInventoryChangesRequest.md)
 - [SquareConnect::BatchRetrieveInventoryChangesResponse](BatchRetrieveInventoryChangesResponse.md)
 - [SquareConnect::BatchRetrieveInventoryCountsRequest](BatchRetrieveInventoryCountsRequest.md)
 - [SquareConnect::BatchRetrieveInventoryCountsResponse](BatchRetrieveInventoryCountsResponse.md)
 - [SquareConnect::BatchRetrieveOrdersRequest](BatchRetrieveOrdersRequest.md)
 - [SquareConnect::BatchRetrieveOrdersResponse](BatchRetrieveOrdersResponse.md)
 - [SquareConnect::BatchUpsertCatalogObjectsRequest](BatchUpsertCatalogObjectsRequest.md)
 - [SquareConnect::BatchUpsertCatalogObjectsResponse](BatchUpsertCatalogObjectsResponse.md)
 - [SquareConnect::BreakType](BreakType.md)
 - [SquareConnect::BusinessHours](BusinessHours.md)
 - [SquareConnect::BusinessHoursPeriod](BusinessHoursPeriod.md)
 - [SquareConnect::CaptureTransactionRequest](CaptureTransactionRequest.md)
 - [SquareConnect::CaptureTransactionResponse](CaptureTransactionResponse.md)
 - [SquareConnect::Card](Card.md)
 - [SquareConnect::CardBrand](CardBrand.md)
 - [SquareConnect::CatalogCategory](CatalogCategory.md)
 - [SquareConnect::CatalogDiscount](CatalogDiscount.md)
 - [SquareConnect::CatalogDiscountType](CatalogDiscountType.md)
 - [SquareConnect::CatalogIdMapping](CatalogIdMapping.md)
 - [SquareConnect::CatalogImage](CatalogImage.md)
 - [SquareConnect::CatalogInfoRequest](CatalogInfoRequest.md)
 - [SquareConnect::CatalogInfoResponse](CatalogInfoResponse.md)
 - [SquareConnect::CatalogInfoResponseLimits](CatalogInfoResponseLimits.md)
 - [SquareConnect::CatalogItem](CatalogItem.md)
 - [SquareConnect::CatalogItemModifierListInfo](CatalogItemModifierListInfo.md)
 - [SquareConnect::CatalogItemOption](CatalogItemOption.md)
 - [SquareConnect::CatalogItemOptionForItem](CatalogItemOptionForItem.md)
 - [SquareConnect::CatalogItemOptionValue](CatalogItemOptionValue.md)
 - [SquareConnect::CatalogItemOptionValueForItemVariation](CatalogItemOptionValueForItemVariation.md)
 - [SquareConnect::CatalogItemProductType](CatalogItemProductType.md)
 - [SquareConnect::CatalogItemVariation](CatalogItemVariation.md)
 - [SquareConnect::CatalogMeasurementUnit](CatalogMeasurementUnit.md)
 - [SquareConnect::CatalogModifier](CatalogModifier.md)
 - [SquareConnect::CatalogModifierList](CatalogModifierList.md)
 - [SquareConnect::CatalogModifierListSelectionType](CatalogModifierListSelectionType.md)
 - [SquareConnect::CatalogModifierOverride](CatalogModifierOverride.md)
 - [SquareConnect::CatalogObject](CatalogObject.md)
 - [SquareConnect::CatalogObjectBatch](CatalogObjectBatch.md)
 - [SquareConnect::CatalogObjectType](CatalogObjectType.md)
 - [SquareConnect::CatalogPricingRule](CatalogPricingRule.md)
 - [SquareConnect::CatalogPricingType](CatalogPricingType.md)
 - [SquareConnect::CatalogProductSet](CatalogProductSet.md)
 - [SquareConnect::CatalogQuery](CatalogQuery.md)
 - [SquareConnect::CatalogQueryExact](CatalogQueryExact.md)
 - [SquareConnect::CatalogQueryItemVariationsForItemOptionValues](CatalogQueryItemVariationsForItemOptionValues.md)
 - [SquareConnect::CatalogQueryItemsForItemOptions](CatalogQueryItemsForItemOptions.md)
 - [SquareConnect::CatalogQueryItemsForModifierList](CatalogQueryItemsForModifierList.md)
 - [SquareConnect::CatalogQueryItemsForTax](CatalogQueryItemsForTax.md)
 - [SquareConnect::CatalogQueryPrefix](CatalogQueryPrefix.md)
 - [SquareConnect::CatalogQueryRange](CatalogQueryRange.md)
 - [SquareConnect::CatalogQuerySortedAttribute](CatalogQuerySortedAttribute.md)
 - [SquareConnect::CatalogQueryText](CatalogQueryText.md)
 - [SquareConnect::CatalogTax](CatalogTax.md)
 - [SquareConnect::CatalogTimePeriod](CatalogTimePeriod.md)
 - [SquareConnect::CatalogV1Id](CatalogV1Id.md)
 - [SquareConnect::ChargeRequest](ChargeRequest.md)
 - [SquareConnect::ChargeRequestAdditionalRecipient](ChargeRequestAdditionalRecipient.md)
 - [SquareConnect::ChargeResponse](ChargeResponse.md)
 - [SquareConnect::Checkout](Checkout.md)
 - [SquareConnect::Coordinates](Coordinates.md)
 - [SquareConnect::Country](Country.md)
 - [SquareConnect::CreateBreakTypeRequest](CreateBreakTypeRequest.md)
 - [SquareConnect::CreateBreakTypeResponse](CreateBreakTypeResponse.md)
 - [SquareConnect::CreateCheckoutRequest](CreateCheckoutRequest.md)
 - [SquareConnect::CreateCheckoutResponse](CreateCheckoutResponse.md)
 - [SquareConnect::CreateCustomerCardRequest](CreateCustomerCardRequest.md)
 - [SquareConnect::CreateCustomerCardResponse](CreateCustomerCardResponse.md)
 - [SquareConnect::CreateCustomerRequest](CreateCustomerRequest.md)
 - [SquareConnect::CreateCustomerResponse](CreateCustomerResponse.md)
 - [SquareConnect::CreateMobileAuthorizationCodeRequest](CreateMobileAuthorizationCodeRequest.md)
 - [SquareConnect::CreateMobileAuthorizationCodeResponse](CreateMobileAuthorizationCodeResponse.md)
 - [SquareConnect::CreateOrderRequest](CreateOrderRequest.md)
 - [SquareConnect::CreateOrderRequestDiscount](CreateOrderRequestDiscount.md)
 - [SquareConnect::CreateOrderRequestLineItem](CreateOrderRequestLineItem.md)
 - [SquareConnect::CreateOrderRequestModifier](CreateOrderRequestModifier.md)
 - [SquareConnect::CreateOrderRequestTax](CreateOrderRequestTax.md)
 - [SquareConnect::CreateOrderResponse](CreateOrderResponse.md)
 - [SquareConnect::CreateRefundRequest](CreateRefundRequest.md)
 - [SquareConnect::CreateRefundResponse](CreateRefundResponse.md)
 - [SquareConnect::CreateShiftRequest](CreateShiftRequest.md)
 - [SquareConnect::CreateShiftResponse](CreateShiftResponse.md)
 - [SquareConnect::Currency](Currency.md)
 - [SquareConnect::Customer](Customer.md)
 - [SquareConnect::CustomerCreationSource](CustomerCreationSource.md)
 - [SquareConnect::CustomerCreationSourceFilter](CustomerCreationSourceFilter.md)
 - [SquareConnect::CustomerFilter](CustomerFilter.md)
 - [SquareConnect::CustomerGroupInfo](CustomerGroupInfo.md)
 - [SquareConnect::CustomerInclusionExclusion](CustomerInclusionExclusion.md)
 - [SquareConnect::CustomerPreferences](CustomerPreferences.md)
 - [SquareConnect::CustomerQuery](CustomerQuery.md)
 - [SquareConnect::CustomerSort](CustomerSort.md)
 - [SquareConnect::CustomerSortField](CustomerSortField.md)
 - [SquareConnect::DateRange](DateRange.md)
 - [SquareConnect::DayOfWeek](DayOfWeek.md)
 - [SquareConnect::DeleteBreakTypeRequest](DeleteBreakTypeRequest.md)
 - [SquareConnect::DeleteBreakTypeResponse](DeleteBreakTypeResponse.md)
 - [SquareConnect::DeleteCatalogObjectRequest](DeleteCatalogObjectRequest.md)
 - [SquareConnect::DeleteCatalogObjectResponse](DeleteCatalogObjectResponse.md)
 - [SquareConnect::DeleteCustomerCardRequest](DeleteCustomerCardRequest.md)
 - [SquareConnect::DeleteCustomerCardResponse](DeleteCustomerCardResponse.md)
 - [SquareConnect::DeleteCustomerRequest](DeleteCustomerRequest.md)
 - [SquareConnect::DeleteCustomerResponse](DeleteCustomerResponse.md)
 - [SquareConnect::DeleteShiftRequest](DeleteShiftRequest.md)
 - [SquareConnect::DeleteShiftResponse](DeleteShiftResponse.md)
 - [SquareConnect::Device](Device.md)
 - [SquareConnect::Employee](Employee.md)
 - [SquareConnect::EmployeeStatus](EmployeeStatus.md)
 - [SquareConnect::EmployeeWage](EmployeeWage.md)
 - [SquareConnect::Error](Error.md)
 - [SquareConnect::ErrorCategory](ErrorCategory.md)
 - [SquareConnect::ErrorCode](ErrorCode.md)
 - [SquareConnect::GetBreakTypeRequest](GetBreakTypeRequest.md)
 - [SquareConnect::GetBreakTypeResponse](GetBreakTypeResponse.md)
 - [SquareConnect::GetEmployeeWageRequest](GetEmployeeWageRequest.md)
 - [SquareConnect::GetEmployeeWageResponse](GetEmployeeWageResponse.md)
 - [SquareConnect::GetShiftRequest](GetShiftRequest.md)
 - [SquareConnect::GetShiftResponse](GetShiftResponse.md)
 - [SquareConnect::InventoryAdjustment](InventoryAdjustment.md)
 - [SquareConnect::InventoryAlertType](InventoryAlertType.md)
 - [SquareConnect::InventoryChange](InventoryChange.md)
 - [SquareConnect::InventoryChangeType](InventoryChangeType.md)
 - [SquareConnect::InventoryCount](InventoryCount.md)
 - [SquareConnect::InventoryPhysicalCount](InventoryPhysicalCount.md)
 - [SquareConnect::InventoryState](InventoryState.md)
 - [SquareConnect::InventoryTransfer](InventoryTransfer.md)
 - [SquareConnect::ItemVariationLocationOverrides](ItemVariationLocationOverrides.md)
 - [SquareConnect::ListAdditionalRecipientReceivableRefundsRequest](ListAdditionalRecipientReceivableRefundsRequest.md)
 - [SquareConnect::ListAdditionalRecipientReceivableRefundsResponse](ListAdditionalRecipientReceivableRefundsResponse.md)
 - [SquareConnect::ListAdditionalRecipientReceivablesRequest](ListAdditionalRecipientReceivablesRequest.md)
 - [SquareConnect::ListAdditionalRecipientReceivablesResponse](ListAdditionalRecipientReceivablesResponse.md)
 - [SquareConnect::ListBreakTypesRequest](ListBreakTypesRequest.md)
 - [SquareConnect::ListBreakTypesResponse](ListBreakTypesResponse.md)
 - [SquareConnect::ListCatalogRequest](ListCatalogRequest.md)
 - [SquareConnect::ListCatalogResponse](ListCatalogResponse.md)
 - [SquareConnect::ListCustomersRequest](ListCustomersRequest.md)
 - [SquareConnect::ListCustomersResponse](ListCustomersResponse.md)
 - [SquareConnect::ListEmployeeWagesRequest](ListEmployeeWagesRequest.md)
 - [SquareConnect::ListEmployeeWagesResponse](ListEmployeeWagesResponse.md)
 - [SquareConnect::ListEmployeesRequest](ListEmployeesRequest.md)
 - [SquareConnect::ListEmployeesResponse](ListEmployeesResponse.md)
 - [SquareConnect::ListLocationsRequest](ListLocationsRequest.md)
 - [SquareConnect::ListLocationsResponse](ListLocationsResponse.md)
 - [SquareConnect::ListRefundsRequest](ListRefundsRequest.md)
 - [SquareConnect::ListRefundsResponse](ListRefundsResponse.md)
 - [SquareConnect::ListTransactionsRequest](ListTransactionsRequest.md)
 - [SquareConnect::ListTransactionsResponse](ListTransactionsResponse.md)
 - [SquareConnect::ListWorkweekConfigsRequest](ListWorkweekConfigsRequest.md)
 - [SquareConnect::ListWorkweekConfigsResponse](ListWorkweekConfigsResponse.md)
 - [SquareConnect::Location](Location.md)
 - [SquareConnect::LocationCapability](LocationCapability.md)
 - [SquareConnect::LocationStatus](LocationStatus.md)
 - [SquareConnect::LocationType](LocationType.md)
 - [SquareConnect::MeasurementUnit](MeasurementUnit.md)
 - [SquareConnect::MeasurementUnitArea](MeasurementUnitArea.md)
 - [SquareConnect::MeasurementUnitCustom](MeasurementUnitCustom.md)
 - [SquareConnect::MeasurementUnitGeneric](MeasurementUnitGeneric.md)
 - [SquareConnect::MeasurementUnitLength](MeasurementUnitLength.md)
 - [SquareConnect::MeasurementUnitVolume](MeasurementUnitVolume.md)
 - [SquareConnect::MeasurementUnitWeight](MeasurementUnitWeight.md)
 - [SquareConnect::ModelBreak](ModelBreak.md)
 - [SquareConnect::Money](Money.md)
 - [SquareConnect::ObtainTokenRequest](ObtainTokenRequest.md)
 - [SquareConnect::ObtainTokenResponse](ObtainTokenResponse.md)
 - [SquareConnect::Order](Order.md)
 - [SquareConnect::OrderEntry](OrderEntry.md)
 - [SquareConnect::OrderFulfillment](OrderFulfillment.md)
 - [SquareConnect::OrderFulfillmentPickupDetails](OrderFulfillmentPickupDetails.md)
 - [SquareConnect::OrderFulfillmentPickupDetailsScheduleType](OrderFulfillmentPickupDetailsScheduleType.md)
 - [SquareConnect::OrderFulfillmentRecipient](OrderFulfillmentRecipient.md)
 - [SquareConnect::OrderFulfillmentState](OrderFulfillmentState.md)
 - [SquareConnect::OrderFulfillmentType](OrderFulfillmentType.md)
 - [SquareConnect::OrderLineItem](OrderLineItem.md)
 - [SquareConnect::OrderLineItemDiscount](OrderLineItemDiscount.md)
 - [SquareConnect::OrderLineItemDiscountScope](OrderLineItemDiscountScope.md)
 - [SquareConnect::OrderLineItemDiscountType](OrderLineItemDiscountType.md)
 - [SquareConnect::OrderLineItemModifier](OrderLineItemModifier.md)
 - [SquareConnect::OrderLineItemTax](OrderLineItemTax.md)
 - [SquareConnect::OrderLineItemTaxScope](OrderLineItemTaxScope.md)
 - [SquareConnect::OrderLineItemTaxType](OrderLineItemTaxType.md)
 - [SquareConnect::OrderMoneyAmounts](OrderMoneyAmounts.md)
 - [SquareConnect::OrderQuantityUnit](OrderQuantityUnit.md)
 - [SquareConnect::OrderReturn](OrderReturn.md)
 - [SquareConnect::OrderReturnDiscount](OrderReturnDiscount.md)
 - [SquareConnect::OrderReturnLineItem](OrderReturnLineItem.md)
 - [SquareConnect::OrderReturnLineItemModifier](OrderReturnLineItemModifier.md)
 - [SquareConnect::OrderReturnServiceCharge](OrderReturnServiceCharge.md)
 - [SquareConnect::OrderReturnTax](OrderReturnTax.md)
 - [SquareConnect::OrderRoundingAdjustment](OrderRoundingAdjustment.md)
 - [SquareConnect::OrderServiceCharge](OrderServiceCharge.md)
 - [SquareConnect::OrderServiceChargeCalculationPhase](OrderServiceChargeCalculationPhase.md)
 - [SquareConnect::OrderSource](OrderSource.md)
 - [SquareConnect::OrderState](OrderState.md)
 - [SquareConnect::Product](Product.md)
 - [SquareConnect::Refund](Refund.md)
 - [SquareConnect::RefundStatus](RefundStatus.md)
 - [SquareConnect::RegisterDomainRequest](RegisterDomainRequest.md)
 - [SquareConnect::RegisterDomainResponse](RegisterDomainResponse.md)
 - [SquareConnect::RegisterDomainResponseStatus](RegisterDomainResponseStatus.md)
 - [SquareConnect::RenewTokenRequest](RenewTokenRequest.md)
 - [SquareConnect::RenewTokenResponse](RenewTokenResponse.md)
 - [SquareConnect::RetrieveCatalogObjectRequest](RetrieveCatalogObjectRequest.md)
 - [SquareConnect::RetrieveCatalogObjectResponse](RetrieveCatalogObjectResponse.md)
 - [SquareConnect::RetrieveCustomerRequest](RetrieveCustomerRequest.md)
 - [SquareConnect::RetrieveCustomerResponse](RetrieveCustomerResponse.md)
 - [SquareConnect::RetrieveEmployeeRequest](RetrieveEmployeeRequest.md)
 - [SquareConnect::RetrieveEmployeeResponse](RetrieveEmployeeResponse.md)
 - [SquareConnect::RetrieveInventoryAdjustmentRequest](RetrieveInventoryAdjustmentRequest.md)
 - [SquareConnect::RetrieveInventoryAdjustmentResponse](RetrieveInventoryAdjustmentResponse.md)
 - [SquareConnect::RetrieveInventoryChangesRequest](RetrieveInventoryChangesRequest.md)
 - [SquareConnect::RetrieveInventoryChangesResponse](RetrieveInventoryChangesResponse.md)
 - [SquareConnect::RetrieveInventoryCountRequest](RetrieveInventoryCountRequest.md)
 - [SquareConnect::RetrieveInventoryCountResponse](RetrieveInventoryCountResponse.md)
 - [SquareConnect::RetrieveInventoryPhysicalCountRequest](RetrieveInventoryPhysicalCountRequest.md)
 - [SquareConnect::RetrieveInventoryPhysicalCountResponse](RetrieveInventoryPhysicalCountResponse.md)
 - [SquareConnect::RetrieveTransactionRequest](RetrieveTransactionRequest.md)
 - [SquareConnect::RetrieveTransactionResponse](RetrieveTransactionResponse.md)
 - [SquareConnect::RevokeTokenRequest](RevokeTokenRequest.md)
 - [SquareConnect::RevokeTokenResponse](RevokeTokenResponse.md)
 - [SquareConnect::SearchCatalogObjectsRequest](SearchCatalogObjectsRequest.md)
 - [SquareConnect::SearchCatalogObjectsResponse](SearchCatalogObjectsResponse.md)
 - [SquareConnect::SearchCustomersRequest](SearchCustomersRequest.md)
 - [SquareConnect::SearchCustomersResponse](SearchCustomersResponse.md)
 - [SquareConnect::SearchOrdersCustomerFilter](SearchOrdersCustomerFilter.md)
 - [SquareConnect::SearchOrdersDateTimeFilter](SearchOrdersDateTimeFilter.md)
 - [SquareConnect::SearchOrdersFilter](SearchOrdersFilter.md)
 - [SquareConnect::SearchOrdersFulfillmentFilter](SearchOrdersFulfillmentFilter.md)
 - [SquareConnect::SearchOrdersQuery](SearchOrdersQuery.md)
 - [SquareConnect::SearchOrdersRequest](SearchOrdersRequest.md)
 - [SquareConnect::SearchOrdersResponse](SearchOrdersResponse.md)
 - [SquareConnect::SearchOrdersSort](SearchOrdersSort.md)
 - [SquareConnect::SearchOrdersSortField](SearchOrdersSortField.md)
 - [SquareConnect::SearchOrdersSourceFilter](SearchOrdersSourceFilter.md)
 - [SquareConnect::SearchOrdersStateFilter](SearchOrdersStateFilter.md)
 - [SquareConnect::SearchShiftsRequest](SearchShiftsRequest.md)
 - [SquareConnect::SearchShiftsResponse](SearchShiftsResponse.md)
 - [SquareConnect::Shift](Shift.md)
 - [SquareConnect::ShiftFilter](ShiftFilter.md)
 - [SquareConnect::ShiftFilterStatus](ShiftFilterStatus.md)
 - [SquareConnect::ShiftQuery](ShiftQuery.md)
 - [SquareConnect::ShiftSort](ShiftSort.md)
 - [SquareConnect::ShiftSortField](ShiftSortField.md)
 - [SquareConnect::ShiftStatus](ShiftStatus.md)
 - [SquareConnect::ShiftWage](ShiftWage.md)
 - [SquareConnect::ShiftWorkday](ShiftWorkday.md)
 - [SquareConnect::ShiftWorkdayMatcher](ShiftWorkdayMatcher.md)
 - [SquareConnect::SortOrder](SortOrder.md)
 - [SquareConnect::SourceApplication](SourceApplication.md)
 - [SquareConnect::StandardUnitDescription](StandardUnitDescription.md)
 - [SquareConnect::StandardUnitDescriptionGroup](StandardUnitDescriptionGroup.md)
 - [SquareConnect::TaxCalculationPhase](TaxCalculationPhase.md)
 - [SquareConnect::TaxInclusionType](TaxInclusionType.md)
 - [SquareConnect::Tender](Tender.md)
 - [SquareConnect::TenderCardDetails](TenderCardDetails.md)
 - [SquareConnect::TenderCardDetailsEntryMethod](TenderCardDetailsEntryMethod.md)
 - [SquareConnect::TenderCardDetailsStatus](TenderCardDetailsStatus.md)
 - [SquareConnect::TenderCashDetails](TenderCashDetails.md)
 - [SquareConnect::TenderType](TenderType.md)
 - [SquareConnect::TimeRange](TimeRange.md)
 - [SquareConnect::Transaction](Transaction.md)
 - [SquareConnect::TransactionProduct](TransactionProduct.md)
 - [SquareConnect::UpdateBreakTypeRequest](UpdateBreakTypeRequest.md)
 - [SquareConnect::UpdateBreakTypeResponse](UpdateBreakTypeResponse.md)
 - [SquareConnect::UpdateCustomerRequest](UpdateCustomerRequest.md)
 - [SquareConnect::UpdateCustomerResponse](UpdateCustomerResponse.md)
 - [SquareConnect::UpdateItemModifierListsRequest](UpdateItemModifierListsRequest.md)
 - [SquareConnect::UpdateItemModifierListsResponse](UpdateItemModifierListsResponse.md)
 - [SquareConnect::UpdateItemTaxesRequest](UpdateItemTaxesRequest.md)
 - [SquareConnect::UpdateItemTaxesResponse](UpdateItemTaxesResponse.md)
 - [SquareConnect::UpdateShiftRequest](UpdateShiftRequest.md)
 - [SquareConnect::UpdateShiftResponse](UpdateShiftResponse.md)
 - [SquareConnect::UpdateWorkweekConfigRequest](UpdateWorkweekConfigRequest.md)
 - [SquareConnect::UpdateWorkweekConfigResponse](UpdateWorkweekConfigResponse.md)
 - [SquareConnect::UpsertCatalogObjectRequest](UpsertCatalogObjectRequest.md)
 - [SquareConnect::UpsertCatalogObjectResponse](UpsertCatalogObjectResponse.md)
 - [SquareConnect::V1AdjustInventoryRequest](V1AdjustInventoryRequest.md)
 - [SquareConnect::V1AdjustInventoryRequestAdjustmentType](V1AdjustInventoryRequestAdjustmentType.md)
 - [SquareConnect::V1ApplyFeeRequest](V1ApplyFeeRequest.md)
 - [SquareConnect::V1ApplyModifierListRequest](V1ApplyModifierListRequest.md)
 - [SquareConnect::V1BankAccount](V1BankAccount.md)
 - [SquareConnect::V1BankAccountType](V1BankAccountType.md)
 - [SquareConnect::V1CashDrawerEvent](V1CashDrawerEvent.md)
 - [SquareConnect::V1CashDrawerEventEventType](V1CashDrawerEventEventType.md)
 - [SquareConnect::V1CashDrawerShift](V1CashDrawerShift.md)
 - [SquareConnect::V1CashDrawerShiftEventType](V1CashDrawerShiftEventType.md)
 - [SquareConnect::V1Category](V1Category.md)
 - [SquareConnect::V1CreateCategoryRequest](V1CreateCategoryRequest.md)
 - [SquareConnect::V1CreateDiscountRequest](V1CreateDiscountRequest.md)
 - [SquareConnect::V1CreateEmployeeRoleRequest](V1CreateEmployeeRoleRequest.md)
 - [SquareConnect::V1CreateFeeRequest](V1CreateFeeRequest.md)
 - [SquareConnect::V1CreateItemRequest](V1CreateItemRequest.md)
 - [SquareConnect::V1CreateModifierListRequest](V1CreateModifierListRequest.md)
 - [SquareConnect::V1CreateModifierOptionRequest](V1CreateModifierOptionRequest.md)
 - [SquareConnect::V1CreatePageRequest](V1CreatePageRequest.md)
 - [SquareConnect::V1CreateRefundRequest](V1CreateRefundRequest.md)
 - [SquareConnect::V1CreateRefundRequestType](V1CreateRefundRequestType.md)
 - [SquareConnect::V1CreateVariationRequest](V1CreateVariationRequest.md)
 - [SquareConnect::V1DeleteCategoryRequest](V1DeleteCategoryRequest.md)
 - [SquareConnect::V1DeleteDiscountRequest](V1DeleteDiscountRequest.md)
 - [SquareConnect::V1DeleteFeeRequest](V1DeleteFeeRequest.md)
 - [SquareConnect::V1DeleteItemRequest](V1DeleteItemRequest.md)
 - [SquareConnect::V1DeleteModifierListRequest](V1DeleteModifierListRequest.md)
 - [SquareConnect::V1DeleteModifierOptionRequest](V1DeleteModifierOptionRequest.md)
 - [SquareConnect::V1DeletePageCellRequest](V1DeletePageCellRequest.md)
 - [SquareConnect::V1DeletePageRequest](V1DeletePageRequest.md)
 - [SquareConnect::V1DeleteTimecardRequest](V1DeleteTimecardRequest.md)
 - [SquareConnect::V1DeleteTimecardResponse](V1DeleteTimecardResponse.md)
 - [SquareConnect::V1DeleteVariationRequest](V1DeleteVariationRequest.md)
 - [SquareConnect::V1Discount](V1Discount.md)
 - [SquareConnect::V1DiscountColor](V1DiscountColor.md)
 - [SquareConnect::V1DiscountDiscountType](V1DiscountDiscountType.md)
 - [SquareConnect::V1Employee](V1Employee.md)
 - [SquareConnect::V1EmployeeRole](V1EmployeeRole.md)
 - [SquareConnect::V1EmployeeRolePermissions](V1EmployeeRolePermissions.md)
 - [SquareConnect::V1EmployeeStatus](V1EmployeeStatus.md)
 - [SquareConnect::V1Fee](V1Fee.md)
 - [SquareConnect::V1FeeAdjustmentType](V1FeeAdjustmentType.md)
 - [SquareConnect::V1FeeCalculationPhase](V1FeeCalculationPhase.md)
 - [SquareConnect::V1FeeInclusionType](V1FeeInclusionType.md)
 - [SquareConnect::V1FeeType](V1FeeType.md)
 - [SquareConnect::V1InventoryEntry](V1InventoryEntry.md)
 - [SquareConnect::V1Item](V1Item.md)
 - [SquareConnect::V1ItemColor](V1ItemColor.md)
 - [SquareConnect::V1ItemImage](V1ItemImage.md)
 - [SquareConnect::V1ItemType](V1ItemType.md)
 - [SquareConnect::V1ItemVisibility](V1ItemVisibility.md)
 - [SquareConnect::V1ListBankAccountsRequest](V1ListBankAccountsRequest.md)
 - [SquareConnect::V1ListBankAccountsResponse](V1ListBankAccountsResponse.md)
 - [SquareConnect::V1ListCashDrawerShiftsRequest](V1ListCashDrawerShiftsRequest.md)
 - [SquareConnect::V1ListCashDrawerShiftsResponse](V1ListCashDrawerShiftsResponse.md)
 - [SquareConnect::V1ListCategoriesRequest](V1ListCategoriesRequest.md)
 - [SquareConnect::V1ListCategoriesResponse](V1ListCategoriesResponse.md)
 - [SquareConnect::V1ListDiscountsRequest](V1ListDiscountsRequest.md)
 - [SquareConnect::V1ListDiscountsResponse](V1ListDiscountsResponse.md)
 - [SquareConnect::V1ListEmployeeRolesRequest](V1ListEmployeeRolesRequest.md)
 - [SquareConnect::V1ListEmployeeRolesResponse](V1ListEmployeeRolesResponse.md)
 - [SquareConnect::V1ListEmployeesRequest](V1ListEmployeesRequest.md)
 - [SquareConnect::V1ListEmployeesRequestStatus](V1ListEmployeesRequestStatus.md)
 - [SquareConnect::V1ListEmployeesResponse](V1ListEmployeesResponse.md)
 - [SquareConnect::V1ListFeesRequest](V1ListFeesRequest.md)
 - [SquareConnect::V1ListFeesResponse](V1ListFeesResponse.md)
 - [SquareConnect::V1ListInventoryRequest](V1ListInventoryRequest.md)
 - [SquareConnect::V1ListInventoryResponse](V1ListInventoryResponse.md)
 - [SquareConnect::V1ListItemsRequest](V1ListItemsRequest.md)
 - [SquareConnect::V1ListItemsResponse](V1ListItemsResponse.md)
 - [SquareConnect::V1ListLocationsRequest](V1ListLocationsRequest.md)
 - [SquareConnect::V1ListLocationsResponse](V1ListLocationsResponse.md)
 - [SquareConnect::V1ListModifierListsRequest](V1ListModifierListsRequest.md)
 - [SquareConnect::V1ListModifierListsResponse](V1ListModifierListsResponse.md)
 - [SquareConnect::V1ListOrdersRequest](V1ListOrdersRequest.md)
 - [SquareConnect::V1ListOrdersResponse](V1ListOrdersResponse.md)
 - [SquareConnect::V1ListPagesRequest](V1ListPagesRequest.md)
 - [SquareConnect::V1ListPagesResponse](V1ListPagesResponse.md)
 - [SquareConnect::V1ListPaymentsRequest](V1ListPaymentsRequest.md)
 - [SquareConnect::V1ListPaymentsResponse](V1ListPaymentsResponse.md)
 - [SquareConnect::V1ListRefundsRequest](V1ListRefundsRequest.md)
 - [SquareConnect::V1ListRefundsResponse](V1ListRefundsResponse.md)
 - [SquareConnect::V1ListSettlementsRequest](V1ListSettlementsRequest.md)
 - [SquareConnect::V1ListSettlementsRequestStatus](V1ListSettlementsRequestStatus.md)
 - [SquareConnect::V1ListSettlementsResponse](V1ListSettlementsResponse.md)
 - [SquareConnect::V1ListTimecardEventsRequest](V1ListTimecardEventsRequest.md)
 - [SquareConnect::V1ListTimecardEventsResponse](V1ListTimecardEventsResponse.md)
 - [SquareConnect::V1ListTimecardsRequest](V1ListTimecardsRequest.md)
 - [SquareConnect::V1ListTimecardsResponse](V1ListTimecardsResponse.md)
 - [SquareConnect::V1Merchant](V1Merchant.md)
 - [SquareConnect::V1MerchantAccountType](V1MerchantAccountType.md)
 - [SquareConnect::V1MerchantBusinessType](V1MerchantBusinessType.md)
 - [SquareConnect::V1MerchantLocationDetails](V1MerchantLocationDetails.md)
 - [SquareConnect::V1ModifierList](V1ModifierList.md)
 - [SquareConnect::V1ModifierListSelectionType](V1ModifierListSelectionType.md)
 - [SquareConnect::V1ModifierOption](V1ModifierOption.md)
 - [SquareConnect::V1Money](V1Money.md)
 - [SquareConnect::V1Order](V1Order.md)
 - [SquareConnect::V1OrderHistoryEntry](V1OrderHistoryEntry.md)
 - [SquareConnect::V1OrderHistoryEntryAction](V1OrderHistoryEntryAction.md)
 - [SquareConnect::V1OrderState](V1OrderState.md)
 - [SquareConnect::V1Page](V1Page.md)
 - [SquareConnect::V1PageCell](V1PageCell.md)
 - [SquareConnect::V1PageCellObjectType](V1PageCellObjectType.md)
 - [SquareConnect::V1PageCellPlaceholderType](V1PageCellPlaceholderType.md)
 - [SquareConnect::V1Payment](V1Payment.md)
 - [SquareConnect::V1PaymentDiscount](V1PaymentDiscount.md)
 - [SquareConnect::V1PaymentItemDetail](V1PaymentItemDetail.md)
 - [SquareConnect::V1PaymentItemization](V1PaymentItemization.md)
 - [SquareConnect::V1PaymentItemizationItemizationType](V1PaymentItemizationItemizationType.md)
 - [SquareConnect::V1PaymentModifier](V1PaymentModifier.md)
 - [SquareConnect::V1PaymentSurcharge](V1PaymentSurcharge.md)
 - [SquareConnect::V1PaymentSurchargeType](V1PaymentSurchargeType.md)
 - [SquareConnect::V1PaymentTax](V1PaymentTax.md)
 - [SquareConnect::V1PaymentTaxInclusionType](V1PaymentTaxInclusionType.md)
 - [SquareConnect::V1PhoneNumber](V1PhoneNumber.md)
 - [SquareConnect::V1Refund](V1Refund.md)
 - [SquareConnect::V1RefundType](V1RefundType.md)
 - [SquareConnect::V1RemoveFeeRequest](V1RemoveFeeRequest.md)
 - [SquareConnect::V1RemoveModifierListRequest](V1RemoveModifierListRequest.md)
 - [SquareConnect::V1RetrieveBankAccountRequest](V1RetrieveBankAccountRequest.md)
 - [SquareConnect::V1RetrieveBusinessRequest](V1RetrieveBusinessRequest.md)
 - [SquareConnect::V1RetrieveCashDrawerShiftRequest](V1RetrieveCashDrawerShiftRequest.md)
 - [SquareConnect::V1RetrieveEmployeeRequest](V1RetrieveEmployeeRequest.md)
 - [SquareConnect::V1RetrieveEmployeeRoleRequest](V1RetrieveEmployeeRoleRequest.md)
 - [SquareConnect::V1RetrieveItemRequest](V1RetrieveItemRequest.md)
 - [SquareConnect::V1RetrieveModifierListRequest](V1RetrieveModifierListRequest.md)
 - [SquareConnect::V1RetrieveOrderRequest](V1RetrieveOrderRequest.md)
 - [SquareConnect::V1RetrievePaymentRequest](V1RetrievePaymentRequest.md)
 - [SquareConnect::V1RetrieveSettlementRequest](V1RetrieveSettlementRequest.md)
 - [SquareConnect::V1RetrieveTimecardRequest](V1RetrieveTimecardRequest.md)
 - [SquareConnect::V1Settlement](V1Settlement.md)
 - [SquareConnect::V1SettlementEntry](V1SettlementEntry.md)
 - [SquareConnect::V1SettlementEntryType](V1SettlementEntryType.md)
 - [SquareConnect::V1SettlementStatus](V1SettlementStatus.md)
 - [SquareConnect::V1Tender](V1Tender.md)
 - [SquareConnect::V1TenderCardBrand](V1TenderCardBrand.md)
 - [SquareConnect::V1TenderEntryMethod](V1TenderEntryMethod.md)
 - [SquareConnect::V1TenderType](V1TenderType.md)
 - [SquareConnect::V1Timecard](V1Timecard.md)
 - [SquareConnect::V1TimecardEvent](V1TimecardEvent.md)
 - [SquareConnect::V1TimecardEventEventType](V1TimecardEventEventType.md)
 - [SquareConnect::V1UpdateCategoryRequest](V1UpdateCategoryRequest.md)
 - [SquareConnect::V1UpdateDiscountRequest](V1UpdateDiscountRequest.md)
 - [SquareConnect::V1UpdateEmployeeRequest](V1UpdateEmployeeRequest.md)
 - [SquareConnect::V1UpdateEmployeeRoleRequest](V1UpdateEmployeeRoleRequest.md)
 - [SquareConnect::V1UpdateFeeRequest](V1UpdateFeeRequest.md)
 - [SquareConnect::V1UpdateItemRequest](V1UpdateItemRequest.md)
 - [SquareConnect::V1UpdateModifierListRequest](V1UpdateModifierListRequest.md)
 - [SquareConnect::V1UpdateModifierListRequestSelectionType](V1UpdateModifierListRequestSelectionType.md)
 - [SquareConnect::V1UpdateModifierOptionRequest](V1UpdateModifierOptionRequest.md)
 - [SquareConnect::V1UpdateOrderRequest](V1UpdateOrderRequest.md)
 - [SquareConnect::V1UpdateOrderRequestAction](V1UpdateOrderRequestAction.md)
 - [SquareConnect::V1UpdatePageCellRequest](V1UpdatePageCellRequest.md)
 - [SquareConnect::V1UpdatePageRequest](V1UpdatePageRequest.md)
 - [SquareConnect::V1UpdateTimecardRequest](V1UpdateTimecardRequest.md)
 - [SquareConnect::V1UpdateVariationRequest](V1UpdateVariationRequest.md)
 - [SquareConnect::V1Variation](V1Variation.md)
 - [SquareConnect::V1VariationInventoryAlertType](V1VariationInventoryAlertType.md)
 - [SquareConnect::V1VariationPricingType](V1VariationPricingType.md)
 - [SquareConnect::VoidTransactionRequest](VoidTransactionRequest.md)
 - [SquareConnect::VoidTransactionResponse](VoidTransactionResponse.md)
 - [SquareConnect::WebhookEvents](WebhookEvents.md)
 - [SquareConnect::Weekday](Weekday.md)
 - [SquareConnect::WorkweekConfig](WorkweekConfig.md)


## Documentation for Authorization


### oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: `https://connect.squareup.com/oauth2/authorize`
- **Scopes**:
  - BANK_ACCOUNTS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to bank account information associated with the targeted Square account. For example, to call the Connect v1 ListBankAccounts endpoint.
  - CUSTOMERS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to customer information. For example, to call the ListCustomers endpoint.
  - CUSTOMERS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to customer information. For example, to create and update customer profiles.
  - EMPLOYEES_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to employee profile information. For example, to call the Connect v1 Employees API.
  - EMPLOYEES_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to employee profile information. For example, to create and modify employee profiles.
  - INVENTORY_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to inventory information. For example, to call the RetrieveInventoryCount endpoint.
  - INVENTORY_WRITE: __HTTP Method__:  &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to inventory information. For example, to call the BatchChangeInventory endpoint.
  - ITEMS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to product catalog information. For example, to get an  item or a list of items.
  - ITEMS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to product catalog information. For example, to modify or add to a product catalog.
  - MERCHANT_PROFILE_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to business and location information. For example, to obtain a location ID for subsequent activity.
  - ORDERS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to order information. For example, to call the BatchRetrieveOrders endpoint.
  - ORDERS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to order information. For example, to call the CreateCheckout endpoint.
  - PAYMENTS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to transaction and refund information. For example, to call the RetrieveTransaction endpoint.
  - PAYMENTS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to transaction and refunds information. For example, to process payments with the Transactions or Checkout API.
  - PAYMENTS_WRITE_ADDITIONAL_RECIPIENTS: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Allow third party applications to deduct a portion of each transaction amount. __Required__ to use multiparty transaction functionality with the Transactions API.
  - PAYMENTS_WRITE_IN_PERSON: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to transaction and refunds information. For example, to process in-person payments.
  - SETTLEMENTS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to settlement (deposit) information. For example, to call the Connect v1 ListSettlements endpoint.
  - TIMECARDS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to employee timecard information. For example, to call the Connect v1 ListTimecards endpoint.
  - TIMECARDS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to employee timecard information. For example, to create and modify timecards.
  - TIMECARDS_SETTINGS_READ: __HTTP Method__: &#x60;GET&#x60;  Grants read access to employee timecard settings information. For example, to call the GetBreakType endpoint.
  - TIMECARDS_SETTINGS_WRITE: __HTTP Method__: &#x60;POST&#x60;, &#x60;PUT&#x60;, &#x60;DELETE&#x60;  Grants write access to employee timecard settings information. For example, to call the UpdateBreakType endpoint.

### oauth2ClientSecret

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Pagination of V1 Endpoints

V1 Endpoints return pagination information via HTTP headers. In order to obtain
response headers and extract the `batch_token` parameter you will need to follow
the following steps:

1. Use the full information endpoint methods of each API to get the response HTTP
Headers. They are named as their simple counterpart with a `with_http_info` suffix.
Hence `listEmployeeRoles` would be called `list_employee_roles_with_http_info`. This
method returns an array with 3 parameters: `response`, `http_status`, and
`http_headers`.
2. Use `batch_token = api_client.get_v1_batch_token_from_headers(http_headers)`
to extract the token and proceed to get the following page if a token is present.

### Example

```ruby
# load the gem
require 'square_connect'
# setup authorization
SquareConnect.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = SquareConnect::V1EmployeesApi.new
api_client = api_instance.api_client

opts = {
  order: "order_example", # String | The order in which employees are listed in the response, based on their created_at field.Default value: ASC
  limit: 56 # Integer | The maximum integer number of employee entities to return in a single response. Default 100, maximum 200.
}

roles = []
begin
  result, status, headers = api_instance.list_employee_roles_with_http_info(opts)
  roles = roles + result
  opts[:batch_token] = api_client.get_v1_batch_token_from_headers(headers)
rescue SquareConnect::ApiError => e
  puts "Exception when calling V1EmployeesApi#list_employee_roles_with_http_info: #{e}"
end while opts[:batch_token]

p roles
```

License
-------

```
Copyright 2017 Square, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
